@@ -76,7 +76,7 @@ char *camv_rnd_get_info_copyright(void)
 		gds_init(&info);
 
 		gds_append_str(&info, "camv-rnd copyright:\n");
-		gds_append_str(&info, "Copyright (C) Tibor Palinkas 2019..2022\n");
+		gds_append_str(&info, "Copyright (C) Tibor Palinkas 2019..2024\n");
 		gds_append_str(&info, "With some code copied from fellow Ringdove application pcb-rnd\n(see http://www.repo.hu/projects/pcb-rnd)\n\n");
 	}
 	return info.array;
@@ -86,7 +86,7 @@ char *camv_rnd_get_info_websites(const char **url_out)
 {
 	static gds_t info;
 	static int first_time = 1;
-	static const char *URL = "http://repo.hu/projects/camv-rnd\n";
+	static const char *URL = "http://www.repo.hu/projects/camv-rnd\n";
 
 	if (first_time) {
 		first_time = 0;
