@@ -117,19 +117,30 @@ static void camv_main_init(void)
 {
 	camv.lysel = -1;
 	camv_font_init();
-	camv_plug_io_act_init();
 }
 
+static void camv_main_init_actions()
+{
+	camv_plug_io_act_init();
+	camv_main_act_init2();
+	gui_act_init();
+}
+
+
+#ifdef RND_WANT_FLOATING_FHS
+	char *camv_floating_confdir;
+#endif
 
 int main(int argc, char *argv[])
 {
 	int n;
 	rnd_main_args_t ga;
-	char *command_line_file = NULL, *exec_prefix;
+	char *exec_prefix;
+	vtp0_t startscripts = {0};
 
 	rnd_app.package = "camv-rnd";
 	rnd_app.version = CAMV_VERS;
-	rnd_app.url = "http://repo.hu/projects/camv-rnd";
+	rnd_app.url = "http://www.repo.hu/projects/camv-rnd";
 	rnd_app.multi_design = 0;
 	rnd_app.menu_file_paths = menu_file_paths;
 	rnd_app.menu_name_fmt   = menu_name_fmt;
@@ -137,9 +148,17 @@ int main(int argc, char *argv[])
 	menu_file_paths[2] = rnd_concat(CONFDIR, "/", NULL);
 
 
+#ifdef RND_WANT_FLOATING_FHS
+	TODO("This ignores ./configure --confdir; the code is in librnd trunk/src/librnd/scconfig/hooks_common.h, search for ''set up confdir'' -> should save a variant usable here, without prefix");
+	camv_floating_confdir = rnd_concat(rnd_w32_root, "/etc/camv-rnd", NULL);
+	rnd_app.conf_sys_path = rnd_concat(CONFDIR, "/conf_core.lht", NULL);
+#else
+	rnd_app.conf_sys_path = CONFDIR "/conf_core.lht";
+#endif
+
+
 	rnd_app.conf_internal = camv_conf_internal;
 	rnd_app.conf_sysdir_path = CONFDIR;
-	rnd_app.conf_sys_path = CONFDIR "/conf_core.lht";
 	rnd_app.conf_userdir_path = CONF_USER_DIR;
 	rnd_app.conf_user_path = CONF_USER_DIR "/conf_core.lht";
 
@@ -160,13 +179,18 @@ int main(int argc, char *argv[])
 	free(exec_prefix);
 
 	camv_event_init_app();
-	for(n = 1; n < argc; n++)
-		n += rnd_main_args_add(&ga, argv[n], argv[n+1]);
+	for(n = 1; n < argc; n++) {
+		if (strcmp(argv[n], "-s") == 0) {
+			n++;
+			vtp0_append(&startscripts, argv[n]);
+		}
+		else
+			n += rnd_main_args_add(&ga, argv[n], argv[n+1]);
+	}
+
 	rnd_hidlib_init2(pup_buildins, camv_buildins);
 	rnd_hidlib_init3_auto();
 
-	camv_main_act_init2();
-	gui_act_init();
 	camv_main_init();
 	rnd_conf_set(RND_CFR_DESIGN, "editor/view/flip_y", 0, "1", RND_POL_OVERWRITE);
 
@@ -178,8 +202,7 @@ int main(int argc, char *argv[])
 
 /* Initialize actions only when the gui is already known so only the right
    one is registered (there can be only one GUI). */
-TODO("action list");
-/*#include "generated_lists.h"*/
+	camv_main_init_actions();
 
 	if (rnd_main_args_setup2(&ga, &n) != 0) {
 		camv_main_uninit();
@@ -199,6 +222,15 @@ TODO("action list");
 	}
 	camv_group_load_end(&camv);
 
+	for(n = 0; n < startscripts.used; n++) {
+		const char *fn = startscripts.array[n];
+		if (rnd_act_execute_file(&camv.hidlib, fn) != 0) {
+			rnd_message(RND_MSG_ERROR, "Failed to execute start-script '%s'\n", fn);
+			rnd_log_print_uninit_errs("Start-script failure");
+			exit(1);
+		}
+	}
+
 	if (rnd_main_exported(&ga, &camv.hidlib, camv_is_empty(&camv), NULL)) {
 		camv_main_uninit();
 		rnd_main_args_uninit(&ga);
