@@ -83,7 +83,7 @@ long camv_layer_append_to_design(camv_design_t *camv, camv_layer_t *layer)
 			vtp0_append(&camv->layers, layer);
 		}
 		else {
-			vtp0_insert_len(&camv->layers, camv->grp_idx_last, &layer, 1);
+			vtp0_insert_len(&camv->layers, camv->grp_idx_last, (void **)&layer, 1);
 			res = camv->grp_idx_last;
 		}
 	}
@@ -98,7 +98,7 @@ long camv_layer_append_to_design(camv_design_t *camv, camv_layer_t *layer)
 long camv_sublayer_append_after(camv_design_t *camv, camv_layer_t *layer, long idx)
 {
 	idx++;
-	vtp0_insert_len(&camv->layers, idx, &layer, 1);
+	vtp0_insert_len(&camv->layers, idx, (void **)&layer, 1);
 	return idx;
 }
 
