@@ -40,7 +40,8 @@
 #include <librnd/core/rotate.h>
 #include <librnd/font/font.h>
 
-static rnd_font_t embf_, *embf = &embf_, *font = &embf_;
+static rnd_font_t embf_, *embf = &embf_;
+rnd_font_t *camv_font = &embf_;
 double font_scale = 1.0;
 
 #include "font_internal.c"
@@ -74,7 +75,7 @@ static void camv_text_draw_atom_cb(void *cb_ctx, const rnd_glyph_atom_t *a)
 
 static void camv_text_draw(camv_any_obj_t *obj, rnd_hid_gc_t gc, rnd_xform_mx_t *mx)
 {
-	rnd_font_draw_string(font, (unsigned char *)obj->text.s, obj->text.x + obj->text.dx, obj->text.y + obj->text.dy, font_scale, font_scale, obj->text.rot, RND_FONT_MIRROR_Y, 0, 0, 0, RND_FONT_TINY_HIDE, camv_text_draw_atom_cb, gc);
+	rnd_font_draw_string(camv_font, (unsigned char *)obj->text.s, obj->text.x + obj->text.dx, obj->text.y + obj->text.dy, font_scale, font_scale, obj->text.rot, RND_FONT_MIRROR_Y, 0, 0, 0, RND_FONT_TINY_HIDE, camv_text_draw_atom_cb, gc);
 }
 
 static void camv_text_bbox(camv_any_obj_t *obj)
@@ -96,7 +97,7 @@ void camv_text_update(rnd_design_t *hidlib, camv_text_t *text, camv_layer_t *ly)
 	rnd_coord_t cx[4], cy[4], w, h;
 
 	/* measure width and height */
-	rnd_font_string_bbox(cx, cy, font, (unsigned char *)text->s, 0, 0, font_scale, font_scale, 0, RND_FONT_MIRROR_Y, 0, 0);
+	rnd_font_string_bbox(cx, cy, camv_font, (unsigned char *)text->s, 0, 0, font_scale, font_scale, 0, RND_FONT_MIRROR_Y, 0, 0);
 	w = cx[1] - cx[0];
 	h = cy[0] - cy[3];
 
@@ -108,7 +109,7 @@ void camv_text_update(rnd_design_t *hidlib, camv_text_t *text, camv_layer_t *ly)
 		rnd_rotate(&text->dx, &text->dy, 0, 0, cos(rad), sin(rad));
 	}
 
-	rnd_font_string_bbox(text->cx, text->cy, font, (unsigned char *)text->s, text->x + text->dx, text->y + text->dy, font_scale, font_scale, text->rot, RND_FONT_MIRROR_Y, 0, 0);
+	rnd_font_string_bbox(text->cx, text->cy, camv_font, (unsigned char *)text->s, text->x + text->dx, text->y + text->dy, font_scale, font_scale, text->rot, RND_FONT_MIRROR_Y, 0, 0);
 	camv_text_bbox((camv_any_obj_t *)text);
 }
 
