@@ -198,7 +198,7 @@ int camv_save_design(camv_design_t *camv, const char *fn_, const char *fmt)
 		ext = fn + len - 1;
 
 	vtpr_init(&prios);
-	camv_plug_io_list(&prios, fn, fmt, CSCH_IOTYP_DESIGN, LIST_SAVE);
+	camv_plug_io_list(&prios, fn, fmt, CAMV_IOTYP_DESIGN, LIST_SAVE);
 	for(n = 0; n < vtpr_len(&prios); n++) {
 		prio_t *pr = &prios.array[n];
 		if (ext != NULL) {
