@@ -31,8 +31,8 @@
 #include "data.h"
 
 typedef enum camv_io_type_s { /* bitfield so multiple detections (e.g. design-or-layer) can be handled */
-	CSCH_IOTYP_DESIGN  = 1,
-	CSCH_IOTYP_LAYER   = 2
+	CAMV_IOTYP_DESIGN  = 1,
+	CAMV_IOTYP_LAYER   = 2
 } camv_io_type_t;
 
 
