@@ -80,10 +80,10 @@ static void build_st_line1(void)
 	rnd_append_printf(&status.buf,
 	"%m+ "
 	"grid=%$mS  "
-	"kbd=%s",
+	"kbd=%s view: %s",
 	rnd_conf.editor.grid_unit->allow,
 	camv.hidlib.grid,
-	kbd);
+	kbd, ((rnd_conf.editor.view.flip_x ^ rnd_conf.editor.view.flip_y) ? "top" : "bottom"));
 }
 
 static void build_st_help(void)
@@ -102,9 +102,12 @@ static void build_st_help(void)
 
 	rnd_append_printf(&status.buf,
 		"%m+"
-		"grid=%$mS  ",
+		"grid=%$mS\n"
+		"looking from the %s",
 		unit_inv->allow,
-		camv.hidlib.grid);
+		camv.hidlib.grid,
+		((rnd_conf.editor.view.flip_x ^ rnd_conf.editor.view.flip_y) ? "top" : "bottom")
+		);
 }
 
 
