@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  camv-rnd - electronics-related CAM viewer
- *  Copyright (C) 2019 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2024 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -230,15 +230,15 @@ static int exc_parse_header(exc_t *exc, char **line)
 		exc->got_unit = 1;
 		if ((*line)[0] == ',') {
 			char *sep;
-			int len;
+			int len, len2;
 			(*line)++;
 			sep = strchr(*line, '.');
 			if (sep != NULL) {
 				TODO("this expects newline");
 				len = strlen(*line);
-				len = len - (sep - (*line)) - 1;
+				len2 = len - (sep - (*line)) - 1;
 				exc->has_metric_scale = 1;
-				exc->metric_scale = pow(10, len);
+				exc->metric_scale = pow(10, len2);
 				(*line) += len;
 				return 0;
 			}
@@ -249,6 +249,7 @@ static int exc_parse_header(exc_t *exc, char **line)
 				(*line)--; /* so that *line points to ",LZ" again */
 			}
 		}
+		return 0;
 	}
 
 	if (strncmp(*line, "INCH", 4) == 0) {
