@@ -102,7 +102,7 @@
  *                            COPYRIGHT
  *
  *  camv-rnd - electronics-related CAM viewer
- *  Copyright (C) 2019 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2024 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -698,7 +698,7 @@ case 10:
 break;
 case 11:
 #line 76 "gcode.y"
-	{ gcode_append(ctx, PARAM, 0); gcode_append(ctx, yystack.l_mark[-2].chr, -1); }
+	{ gcode_append(ctx, PARAM, 0); gcode_append(ctx, yystack.l_mark[-2].chr, -1)->do_pop = 1; }
 break;
 case 12:
 #line 77 "gcode.y"
