@@ -28,6 +28,10 @@
 
 #include <string.h>
 
+#include "gexpr.h"
+#include <genvector/vtp0.h>
+#include <librnd/core/vtc0.h>
+
 #define GVT_DONT_UNDEF
 #include "gedraw.h"
 #include <genvector/genvector_impl.c>
