@@ -31,7 +31,7 @@
 #include <stdio.h>
 #include <genht/htip.h>
 #include <genht/hash.h>
-#include "genvector/vtp0.h"
+#include <genvector/vtp0.h>
 
 #include <librnd/core/global_typedefs.h>
 #include <librnd/core/vtc0.h>
