@@ -482,7 +482,7 @@ int gexlex(YYSTYPE *lval, ge_expr_prglist_t *ctx_)
 	return c;
 }
 
-TODO("switch over from byacc to byaccic and have a .h");
+TODO("switch over from byacc to byaccic and have a .h")
 int gexparse(ge_expr_prglist_t *lst);
 
 static int geparse_macro_expr(geparse_ctx_t *ctx, ge_expr_prg_t **res) {
@@ -584,7 +584,6 @@ static int geparse_macro_aperture_set(geparse_ctx_t *ctx, ge_aper_macro_t *am)
 {
 	ge_expr_prg_t *e;
 	int idx, c;
-	double d;
 	ge_macro_line_t *line = macro_append(ctx, am);
 
 	READ_NUM(ctx, idx);
