@@ -144,7 +144,6 @@ static camv_any_obj_t *aper_oblong2poly(ge_aper_t *aper, double rot)
 	rnd_coord_t xs = aper->data.oblong.xs, ys = aper->data.oblong.ys, xh, yh;
 	rnd_polyarea_t *pa, *ph, *ptmp;
 	camv_any_obj_t *o;
-	int n;
 
 	TODO("figure if we need rotation");
 
@@ -935,14 +934,14 @@ static void gedraw_do_draw_arc(camv_design_t *camv, gedraw_ctx_t *ctx, camv_laye
 	else {
 		if (is_cw) { /* CW */
 			delta = ang1 - ang2;
-			if (delta < 0) {
+			if (delta <= 0) {
 				delta = 360 + delta;
 			}
 			delta = -delta;
 		}
 		else { /* CCW */
 			delta = ang2 - ang1;
-			if (delta < 0)
+			if (delta <= 0)
 				delta = 360 + delta;
 		}
 	}
