@@ -389,7 +389,7 @@ static void tdx_write_obj(write_ctx_t *ctx, const camv_any_obj_t *obj)
 		case CAMV_OBJ_TEXT: break; /* shouldn't happen */
 		case CAMV_OBJ_ARC:  rnd_fprintf(ctx->f, "\tarc %[4] %[4] %[4] %[4] %f %f\n", obj->arc.cx, obj->arc.cy, obj->arc.r, obj->arc.thick, obj->arc.start+180, -obj->arc.delta); break;
 		case CAMV_OBJ_LINE: rnd_fprintf(ctx->f, "\tline %[4] %[4] %[4] %[4] %[4]\n", obj->line.x1, obj->line.y1, obj->line.x2, obj->line.y2, obj->line.thick); break;
-		case CAMV_OBJ_GRP:  fprintf(ctx->f, "\tgrp %p\n", obj); break;
+		case CAMV_OBJ_GRP:  fprintf(ctx->f, "\tgrp %p\n", (void *)obj); break;
 		case CAMV_OBJ_POLY:
 
 			for(len = n = 0; n < obj->poly.len; n++) {
@@ -414,7 +414,7 @@ static void tdx_write_obj(write_ctx_t *ctx, const camv_any_obj_t *obj)
 static void tdx_write_grp(write_ctx_t *ctx, const camv_grp_t *grp)
 {
 	rnd_cardinal_t n;
-	fprintf(ctx->f, "begin camv_grp v1 %p\n", grp);
+	fprintf(ctx->f, "begin camv_grp v1 %p\n", (void *)grp);
 	for(n = 0; n < grp->len; n++) {
 		assert(grp->objs[n].proto.type != CAMV_OBJ_GRP); /* do not allow group-in-group */
 		tdx_write_obj(ctx, &grp->objs[n]);
@@ -567,7 +567,7 @@ static int camv_tdx_test_load(camv_design_t *camv, const char *fn, FILE *f)
 
 static int camv_tdx_save_prio(const char *fn, const char *fmt, camv_io_type_t type)
 {
-	if ((type & CSCH_IOTYP_DESIGN) == 0)
+	if ((type & CAMV_IOTYP_DESIGN) == 0)
 		return -1;
 
 	if ((rnd_strcasecmp(fmt, "tdx") != 0) && (rnd_strcasecmp(fmt, "tedax") != 0))
