@@ -1,7 +1,7 @@
 #include "crosshair.h"
 #include "data.h"
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_inlines.h>
 
 static void tool_arrow_init(void)
 {
@@ -11,29 +11,29 @@ static void tool_arrow_uninit(void)
 {
 }
 
-static void tool_arrow_press(rnd_hidlib_t *hl)
+static void tool_arrow_press(rnd_design_t *hl)
 {
 }
 
-static void tool_arrow_release(rnd_hidlib_t *hl)
+static void tool_arrow_release(rnd_design_t *hl)
 {
 }
 
-static void tool_arrow_adjust_attached_objects(rnd_hidlib_t *hl)
+static void tool_arrow_adjust_attached_objects(rnd_design_t *hl)
 {
 }
 
 
-static void tool_arrow_draw_attached(rnd_hidlib_t *hl)
+static void tool_arrow_draw_attached(rnd_design_t *hl)
 {
 }
 
-rnd_bool tool_arrow_undo_act(rnd_hidlib_t *hl)
+rnd_bool tool_arrow_undo_act(rnd_design_t *hl)
 {
 	return 0;
 }
 
-rnd_bool tool_arrow_redo_act(rnd_hidlib_t *hl)
+rnd_bool tool_arrow_redo_act(rnd_design_t *hl)
 {
 	return 0;
 }
