@@ -1,8 +1,8 @@
 #include "crosshair.h"
 #include "data.h"
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_inlines.h>
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_inlines.h>
+#include <librnd/core/rnd_conf.h>
 
 static void tool_mobj_init(void)
 {
@@ -12,7 +12,7 @@ static void tool_mobj_uninit(void)
 {
 }
 
-static void tool_mobj_press(rnd_hidlib_t *hl)
+static void tool_mobj_press(rnd_design_t *hl)
 {
 	long lid;
 	rnd_coord_t slop = rnd_gui->coord_per_pix * 3 / 2;
@@ -61,25 +61,25 @@ static void tool_mobj_press(rnd_hidlib_t *hl)
 	}
 }
 
-static void tool_mobj_release(rnd_hidlib_t *hl)
+static void tool_mobj_release(rnd_design_t *hl)
 {
 }
 
-static void tool_mobj_adjust_attached_objects(rnd_hidlib_t *hl)
+static void tool_mobj_adjust_attached_objects(rnd_design_t *hl)
 {
 }
 
 
-static void tool_mobj_draw_attached(rnd_hidlib_t *hl)
+static void tool_mobj_draw_attached(rnd_design_t *hl)
 {
 }
 
-rnd_bool tool_mobj_undo_act(rnd_hidlib_t *hl)
+rnd_bool tool_mobj_undo_act(rnd_design_t *hl)
 {
 	return 0;
 }
 
-rnd_bool tool_mobj_redo_act(rnd_hidlib_t *hl)
+rnd_bool tool_mobj_redo_act(rnd_design_t *hl)
 {
 	return 0;
 }
